import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  scaleOrdinal,
  event
} from 'd3';

import { loadData } from './loadData';
import { dropdownMenu } from './dropdownMenu';
import { scatterPlot } from './scatterPlot';
import { stemLegend } from './stemLegend';
import { colorLegend } from './colorLegend';

// create color value
const colorScheme = [
  '#1b69a1', '#aec7e8',
  '#ff7f0e', 'yellow',
  '#2ca02c', '#98df8a',
  '#d62728', '#ff9896',
  '#9467bd', '#c5b0d5',
  '#8c564b', '#c49c94',
  '#e377c2', '#f7b6d2',
  '#7f7f7f', '#c7c7c7',
  '#bcbd22', '#dbdb8d',
  '#17becf', '#9edae5'];

let xColumn;
let yColumn;
let input;
let category1;
let category2;

let selectedCate;


loadData().then(data => {
  input = data;
  category1 = [...new Set(input.map(data => data.Major_category))];
  category2 = [...new Set(input.map(data => data.stem))];
  //console.log(category1.sort());
  yColumn = data.columns[5];
  render();
});

const svg = select('svg');
const stemLegendG = svg.append('g')
  .attr('transform', 'translate(780, 20)');

const width = +svg.attr('width');
const height = +svg.attr('height');

const colorValue1 = d => d.Major_category;
//console.log(colorValue)
const colorValue2 = d => d.stem;
const colorScale1 = scaleOrdinal();
const colorScale2 = scaleOrdinal();

const onClick = d => {
  selectedCate = d;
  render();
};

const onYColumnClicked = column => {
  yColumn = column;
  render();
};

// mouseover and out event handler
let tipMouseOver = function(d) {
  let html = d.Major;
  select('.tooltip').html(html)
    .style('left', event.pageX +15 + 'px')
    .style('top', event.pageY - 50 + 'px')
    .transition()
    .duration(200)
    .style('opacity', 0.8);
};

let tipMouseOut = function (d) {
  select('.tooltip').transition()
    .duration(200)
    .style("opacity", 0);
};

const render = () => {
  
  select('#y-menus')
    .call(dropdownMenu, {
      options: input.columns.filter(c => 
        c !== 'Major' &&
        c !== 'Major_category' &&
        c !== 'stem'
      ),
      onOptionClicked: onYColumnClicked,
      selectedOption: yColumn
    });
  
  colorScale1
    .domain(category1)
    .range(colorScheme);
  
  colorScale2
    .domain(category2)
    .range(2);
  
  svg.call(scatterPlot, {
    xValue: d => d.Major_category,
    //xAxisLabel: xColumn,
    yValue: d => d[yColumn],
    //yAxisLabel: yColumn,
    circleRadius: 8,
    margin: { top: 10, right: 100, bottom: 300, left: 70 },
    width,
    height,
    data: input,
    colorScale1,
    colorValue1,
    selectedCate,
    tipMouseOver,
    tipMouseOut
  });
  
  stemLegendG.call(stemLegend, {
    circleRadius: 9,
    colorScale2,
    colorValue2,
    selectedCate,
    onClick
  });
  
  select('body').append("div")
    .attr("class", "tooltip")
    .style("opacity", 0);
  
};

