import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  format,
  scalePoint
} from 'd3';

export const scatterPlot = (selection, props) => {
  const {
    xValue,
    xAxisLabel,
    yValue,
    circleRadius,
    yAxisLabel,
    margin,
    width,
    height,
    data,
    colorScale1,
    colorValue1,
    selectedCate,
    tipMouseOver,
    tipMouseOut
  } = props;
  
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scalePoint()
    .domain(data.map(xValue))
    .range([0, innerWidth])
    .padding(0.8);
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  
  const g = selection.selectAll('.container').data([null]);
  const gEnter = g
    .enter().append('g')
      .attr('class', 'container');
  gEnter
    .merge(g)
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const AxisTickFormat = number => 
    (number > 1) 
      ? format('.2s')(number)
      : number = number;
  
  const xAxis = axisBottom(xScale)
    .tickFormat(AxisTickFormat)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  const yAxis = axisLeft(yScale)
    .tickFormat(AxisTickFormat)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  const yAxisG = g.select('.y-axis');
  const yAxisGEnter = gEnter
    .append('g')
      .attr('class', 'y-axis');
  
  yAxisG
    .merge(yAxisGEnter)
      .call(yAxis)
      .selectAll('.domain').remove();
  
  const yAxisLabelText = yAxisGEnter
    .append('text')
      .attr('class', 'axis-label')
      .attr('y', -50)
      .attr('fill', 'black')
    .merge(yAxisG.select('.axis-label'))
      .attr('x', -innerHeight / 2)
      .text(yAxisLabel);
  
  const xAxisG = g.select('.x-axis');
  const xAxisGEnter = gEnter
    .append('g')
      .attr('class', 'x-axis');
  
  xAxisG
    .merge(xAxisGEnter)
      .attr('transform', `translate(0,${innerHeight})`)
      .call(xAxis)
      .selectAll('.domain').remove();
  
  const xAxisLabelText = xAxisGEnter
  .append('text')
    .attr('class', 'axis-label')
    .attr('y', 75)
    .attr('fill', 'black')
  .merge(xAxisG.select('.axis-label'))
    .attr('x', innerWidth / 2)
    .text(xAxisLabel);
  
  xAxisGEnter.selectAll('text')
    .attr("transform", "rotate(-45)")
    .style("text-anchor", "end");
  
  const circles = g.merge(gEnter)
    .selectAll('circle').data(data);
  circles
    .enter().append('circle')
      .attr('cx', innerWidth/2)
      .attr('cy', innerHeight)
      .attr('fill', d => colorScale1(colorValue1(d)))
      .attr('r', 0)
      .on('mouseover', tipMouseOver)
      .on('mouseout', tipMouseOut)
    .merge(circles)
    .transition().duration(500)
    .delay((d, i) => i * 5)
      .attr('cy', d => yScale(yValue(d)))
      //.attr('cx', d => xScale(xValue(d)))
      .attr('cx', d => 
        (selectedCate === d.stem)
        ? (xScale(xValue(d)) + Math.random() * 50)
        : (xScale(xValue(d)) + Math.random() * 30))
      .attr('r', d => 
        (selectedCate === d.stem)
        ? 5
        : circleRadius)
      .attr('opacity', d => 
        (!selectedCate || selectedCate === d.stem)
        ? 0.8
        : 0.1)
      .attr('stroke', d => 
        (selectedCate === d.stem)
        ? '#6d6863'
        : null);
};